==> igniteui-angular-charts-16.0.0.tgz: package/esm2015/lib/SlowStochasticOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { SlowStochasticOscillatorIndicatorStrategy } from "./SlowStochasticOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
import { Brush } from "igniteui-angular-core";
/**
 * @hidden
 */
export let SlowStochasticOscillatorIndicator = /*@__PURE__*/ (() => {
    class SlowStochasticOscillatorIndicator extends StrategyBasedIndicator {
        constructor() {
            super();
            this.trendLineBrush = ((() => {
                let $ret = new Brush();
                $ret.fill = "#565656";
                return $ret;
            })());
            this.trendLineType = 10;
            this.trendLinePeriod = 3;
        }
        get_ul() {
            return new SlowStochasticOscillatorIndicatorStrategy();
        }
        get ul() {
            return this.get_ul();
        }
        get_uy() {
            return SlowStochasticOscillatorIndicator.$;
        }
        get uy() {
            return this.get_uy();
        }
        get u6() {
            return typeGetValue(this.c(SlowStochasticOscillatorIndicator.u7));
        }
        set u6(a) {
            this.h(SlowStochasticOscillatorIndicator.u7, a);
        }
        ur() {
            return this.u6;
        }
        u0(a) {
            this.u6 = a;
        }
    }
    SlowStochasticOscillatorIndicator.$t = markType(SlowStochasticOscillatorIndicator, 'SlowStochasticOscillatorIndicator', StrategyBasedIndicator.$);
    SlowStochasticOscillatorIndicator.u7 = StrategyBasedIndicator.u3(14, SlowStochasticOscillatorIndicator.$);
    return SlowStochasticOscillatorIndicator;
})();

==> igniteui-angular-charts-17.2.1.tgz: package/esm2015/lib/SlowStochasticOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { SlowStochasticOscillatorIndicatorStrategy } from "./SlowStochasticOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
import { Brush } from "igniteui-angular-core";
/**
 * @hidden
 */
export let SlowStochasticOscillatorIndicator = /*@__PURE__*/ (() => {
    class SlowStochasticOscillatorIndicator extends StrategyBasedIndicator {
        constructor() {
            super();
            this.trendLineBrush = ((() => {
                let $ret = new Brush();
                $ret.fill = "#565656";
                return $ret;
            })());
            this.trendLineType = 10;
            this.trendLinePeriod = 3;
        }
        bg() {
            return new SlowStochasticOscillatorIndicator();
        }
        get_yz() {
            return new SlowStochasticOscillatorIndicatorStrategy();
        }
        get yz() {
            return this.get_yz();
        }
        get_zc() {
            return SlowStochasticOscillatorIndicator.$;
        }
        get zc() {
            return this.get_zc();
        }
        get zk() {
            return typeGetValue(this.c(SlowStochasticOscillatorIndicator.zl));
        }
        set zk(a) {
            this.h(SlowStochasticOscillatorIndicator.zl, a);
        }
        y5() {
            return this.zk;
        }
        ze(a) {
            this.zk = a;
        }
    }
    SlowStochasticOscillatorIndicator.$t = markType(SlowStochasticOscillatorIndicator, 'SlowStochasticOscillatorIndicator', StrategyBasedIndicator.$);
    SlowStochasticOscillatorIndicator.zl = StrategyBasedIndicator.zh(14, SlowStochasticOscillatorIndicator.$);
    return SlowStochasticOscillatorIndicator;
})();
